import { ServerAPI } from "./lib/ServerAPI";

class User {
    constructor() {
        this.user = undefined;
        this.avatar = undefined;
        this.wxid = undefined;
        this.email = undefined;
        this.session = undefined;
        this.uuid = undefined;
    }

    static getLocalUser() {
        try {
            let user = User.formatLocalUser(JSON.parse(window.localStorage['user']));
            return user;
        } catch (e) {
            return undefined;
        }
    }

    static formatLocalUser(data) {
        try {
            let user = new User();
            user.uuid = data.uuid;
            user.session = data.session;
            user.username = data.username;
            user.email = data.email;
            user.wxid = data.wxid;
            user.avatar = data.avatar;
            return user;
        } catch (e) {
            return undefined;
        }
    }

    static formatUser(data) {
        try {
            let user = new User();
            user.uuid = data.uuid;
            user.session = data.session;
            user.username = data.username;
            user.email = data.email;
            user.wxid = data.wxid;
            user.avatar = import.meta.env.VITE_API_URL + data.avatar;
            return user;
        } catch (e) {
            return undefined;
        }
    }

    static setLocalUser(user) {
        window.localStorage['user'] = JSON.stringify(user);
    }

    getPermissions(callback = function () { }) {
        //检查缓存
        if (this.permissionsCache != undefined) {
            callback(this.permissionsCache);
            return;
        }
        ServerAPI.getPermissions(this.uuid, this.session, (res) => {
            if (res == undefined || res.code != 0) {
                callback();
            }
            callback(res.data);
            this.permissionsCache = res.data;
        });
    }

    getPermissions_sync() {
        return new Promise((solve) => {
            this.getPermissions(solve);
        });
    }
}

class _App {
    constructor() {
        this.user = User.getLocalUser();
    }

    setUser(user) {
        this.user = user;
    }

    cleanUser() {
        this.user = undefined;
        try {
            window.localStorage.removeItem('user');
        } catch (e) {

        }
    }

    hasUser() {
        return this.user instanceof User;
    }

    refershUser(userJson) {
        let user = User.formatUser(userJson);
        this.setUser(user);
        User.setLocalUser(user);
    }
}

let App = new _App();

export {
    App
}